watcher-package: watcher: Watch the File System for Changes

watcher-packageR Documentation

watcher: Watch the File System for Changes

Description

R binding for 'libfswatch', a file system monitoring library. Watch files, or directories recursively, for changes in the background. Log activity, or call an R function, upon every change event.

Author(s)

Maintainer: Charlie Gao charlie.gao@posit.co (ORCID)

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

  • Enrico M. Crisostomo (libfswatch library) [copyright holder]

  • Alan Dipert (libfswatch library) [copyright holder]

See Also

Useful links:


watcher documentation built on May 9, 2026, 9:07 a.m.