Learn R Programming

watcher (version 0.2.1)

watcher-package: watcher: Watch the File System for Changes

Description

R binding for 'libfswatch', a file system monitoring library. Watch files, or directories recursively, for changes in the background. Log activity, or call an R function, upon every change event.

Arguments

Author

Maintainer: Charlie Gao [email protected] (ORCID)

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

  • Enrico M. Crisostomo (libfswatch library) [copyright holder]

  • Alan Dipert (libfswatch library) [copyright holder]

See Also