R binding for 'libfswatch', a file system monitoring library. Watch files, or directories recursively, for changes in the background. Log activity, or call an R function, upon every change event.
Maintainer: Charlie Gao [email protected] (ORCID)
Authors:
Charlie Gao [email protected] (ORCID)
Other contributors:
Posit Software, PBC (ROR) [copyright holder, funder]
Enrico M. Crisostomo (libfswatch library) [copyright holder]
Alan Dipert (libfswatch library) [copyright holder]
Useful links: